@@ -56,7 +56,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     stationDeparture             = new QMaemo5ValueButton(tr("Station from"));
     stationArrival               = new QMaemo5ValueButton(tr("Station to"));
-    QPushButton *stationSwap     = new QPushButton();
+    QPushButton *stationSwap     = new QPushButton("");
 
     stationDeparture->setValueText(tr("please select"));
     stationDeparture->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
@@ -158,7 +158,7 @@ MainWindow::MainWindow(QWidget *parent)
     {
         QMessageBox::about(this,
                            tr("Welcome to a new version of fahrplan this is new"),
-                           tr("- fixed a dbus related 2 min after start crash<br>- complete rewrite in QT for better portability and a future in meego<br>- adding settings to enable/disable gps autostart<br>- adding settings to enable/disable openstreetmap gps fallback<br>- adding support for mvv-muenchen.de and settings to change the data backend<br>- adding support to enable/disable gps")
+                           tr("- added sbb.ch backend<br>- you now can store the last 20 searched stations and quickly select them.<br>- some small other fixes/improvements")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
@@ -178,6 +178,10 @@ void MainWindow::initBackend()
     {
         backendParser = new parserMvvDe();
         setWindowTitle("Fahrplan (mvv-muenchen.de)");
+    } else if (backendType == "parserSbbCh")
+    {
+        backendParser = new parserSbbCh();
+        setWindowTitle("Fahrplan (sbb.ch)");
     } else
     {
        //fallback is bahn.de
@@ -232,7 +236,7 @@ void MainWindow::stationArrivalClicked()
 void MainWindow::aboutButtonClicked()
 {
     QString version = APP_VER;
-    QString aboutMsg = "by smurfy (maemo@smurfy.de)<br>Version " + version + "<br><br>Current supported databackends:<br><b>bahn.de</b>, <b>mvv-muenchen.de</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>";
+    QString aboutMsg = "by smurfy (maemo@smurfy.de)<br>Version " + version + "<br><br>Current supported databackends:<br><b>bahn.de</b>, <b>mvv-muenchen.de</b>, <b>sbb.ch</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>";
     QMessageBox::about(this,
                        tr("About Fahrplan"),
                        tr(aboutMsg.toAscii()));
@@ -250,9 +254,20 @@ void MainWindow::resultItemClicked()
     QPushButton *button = (QPushButton *)sender();
     ResultItemUserData *data = (ResultItemUserData*)button->userData(0);
 
-    lastSearchDetails = backendParser->getJourneyDetailsData(data->item.detailsUrl);
+    if (detailsLoading != true)
+    {
+        detailsLoading = true;
 
-    showDetailsWindow();
+        lastSearchDetails = backendParser->getJourneyDetailsData(data->item.detailsUrl);
+
+        detailsLoading = false;
+
+        showDetailsWindow();
+    } else
+    {
+        QMaemo5InformationBox::information(this, "<br>Details allready loading, please wait.<br>", QMaemo5InformationBox::DefaultTimeout);
+        return;
+    }
 }
 
 void MainWindow::showDetailsWindow()
@@ -331,7 +346,7 @@ void MainWindow::showDetailsWindow()
         line->setFrameShadow(QFrame::Sunken);
         line->setLineWidth(1);
         QPalette palette = line->palette();
-        palette.setColor(QPalette::Dark, palette.color(QPalette::Highlight));
+        palette.setColor(QPalette::Dark, palette.color(QPalette::Mid));
         line->setPalette(palette);
 
         itemLayout->addWidget(line);
@@ -398,6 +413,7 @@ void MainWindow::showResultWindow()
         return;
     }
 
+    detailsLoading = false;
 
     /*
     qDebug() <<"Results:";
@@ -514,7 +530,7 @@ void MainWindow::showResultWindow()
         line->setFrameShadow(QFrame::Sunken);
         line->setLineWidth(1);
         QPalette palette = line->palette();
-        palette.setColor(QPalette::Dark, palette.color(QPalette::Highlight));
+        palette.setColor(QPalette::Dark, palette.color(QPalette::Mid));
         line->setPalette(palette);
 
         itemLayout->addWidget(line);
@@ -582,6 +598,29 @@ void MainWindow::searchButtonClicked(bool checked)
 
         if (stationDeparture->valueText() != stationArrival->valueText() && stationDeparture->valueText() != tr("please select") && stationArrival->valueText() != tr("please select"))
         {
+            //Store last search data
+            if (settings->value("storelastsearch", true).toBool() ==  true)
+            {
+                QStringList oldList;
+                oldList = settings->value("lastsearch/stations", oldList).toStringList();
+                oldList.append(stationDeparture->valueText().trimmed());
+                oldList.append(stationArrival->valueText().trimmed());
+
+                //We need to reverse the order before removing duplicates
+                //to ensure the latest station is later on the bottom
+                oldList = fahrplanUtils::reverseQStringList(oldList);
+                oldList.removeDuplicates();
+                oldList = fahrplanUtils::reverseQStringList(oldList);
+
+                //We will store only the last active stations used
+                while (oldList.count() > 20)
+                {
+                    oldList.removeFirst();
+                }
+
+                settings->setValue("lastsearch/stations", oldList);
+            }
+
             searchButton->setEnabled(false);
             lastSearchResult = backendParser->getJourneyData(stationDeparture->valueText(), stationArrival->valueText(), "", dateSel->currentDate(), timeSel->currentTime(), modeSel->currentIndex());
             showResultWindow();
