@@ -36,12 +36,15 @@
 #include <qgeopositioninfo.h>
 #include <qgeopositioninfosource.h>
 
+#include "parser_abstract.h"
 #include "parser_mobilebahnde.h"
 #include "parser_mvvde.h"
+#include "parser_sbbch.h"
 #include "selectstationdialog.h"
 #include "configdialog.h"
+#include "fahrplanutils.h"
 
-#define APP_VER "0.0.12"
+#define APP_VER "0.0.13"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -96,6 +99,7 @@ private:
 
     parserAbstract *backendParser;
 
+    bool detailsLoading;
     void closeEvent(QCloseEvent *event);
     void showResultWindow();
     void showDetailsWindow();
