@@ -502,8 +502,8 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
 QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude)
 {
     QString zeros      = "0";
-    QString sLongitude = QString::number(longitude).replace(QChar('.'), "").replace(QChar(','), "");
-    QString sLatitude  = QString::number(latitude).replace(QChar('.'), "").replace(QChar(','), "");
+    QString sLongitude = QString::number(longitude).replace(QChar('.'), "");
+    QString sLatitude  = QString::number(latitude).replace(QChar('.'), "");
 
     sLongitude.append(zeros.repeated(8 - sLongitude.count()));
     sLatitude.append(zeros.repeated(8 - sLatitude.count()));
